@@ -1,7 +1,6 @@
-use bpay::api::create_order::{
-    Currency, Env, Goods, GoodsCategory, GoodsType, Order, TerminalType,
+use bpay::api::order::create::{
+    Currency, Env, Goods, GoodsCategory, GoodsType, Request as OrderRequest, TerminalType,
 };
-use bpay::api::Binance;
 use bpay::client::Client;
 use bpay::errors::Result;
 use bpay::utils::create_nonce;
@@ -9,7 +8,7 @@ use tokio;
 
 #[tokio::main]
 async fn main() -> Result<()> {
-    let order = Order {
+    let order = OrderRequest {
         env: Env {
             terminal_type: TerminalType::Web,
         },
@@ -26,7 +25,7 @@ async fn main() -> Result<()> {
     };
 
     let client = Client::from_env();
-    let create_order_result = order.post(&client).await?;
+    let create_order_result = order.create(&client).await?;
     println!(
         "This url can be sent across to complete the payment procedure: {}",
         create_order_result.universal_url
