@@ -16,10 +16,9 @@ tokio = { version = "1.18.0", features = ["rt-multi-thread", "macros"] }
 
  ## Example
  ```
-use bpay::api::create_order::{
-    Currency, Env, Goods, GoodsCategory, GoodsType, Order, TerminalType,
+use bpay::api::order::create::{
+    Currency, Env, Goods, GoodsCategory, GoodsType, Request as OrderRequest, TerminalType,
 };
-use bpay::api::Binance;
 use bpay::client::Client;
 use bpay::utils::create_nonce;
 # #[cfg(test)]
@@ -30,7 +29,7 @@ use tokio;
 #[tokio::main]
 async fn main() {
 
-    let order = Order {
+    let order = OrderRequest {
         env: Env {
             terminal_type: TerminalType::Web,
         },
@@ -70,11 +69,11 @@ async fn main() {
     #     .with_header("content-type", "application/json")
     #     .with_body(response)
     #     .create();
-    let create_order_result = order.post(&client).await.unwrap();
-    match create_order_result.terminal_type {
-        TerminalType::Web => assert!(true),
-        _ => assert!(false),
-    }
+    let create_order_result = order.create(&client).await.unwrap();
+    println!(
+        "This url can be sent across to complete the payment procedure: {}",
+        create_order_result.universal_url
+    );
 }
  ```
 */
